pub(crate) fn observe_log(
tracker: &mut VecDeque<(ExpectedEmit, AddressHashMap<LogCountMap>)>,
log: &Log,
) -> Option<&'static str>Expand description
Fills or checks the expected emits against an emitted log.
Returns the failure reason if the log violates an expectation.